filename INF  "apstat.dat";

** Reads in ASCII file containing the data        **;
** Note y_j = 0 denotes good self assessment and  **;
** y_j = 1 denotes bad self assessment.           **;

** Gender : 1 if male                                **;
** age    : in years                                 **;
** treat  : treatment (1 if auranofin, 0 if placebo) **;

data temp;
  infile inf;
  input gender age trt  y1-y5;
  patient = _n_;  /* Creates patient ID's */
run;

%let y = y;
%let x = int time gender age treat;
%let z = distance;

data XY (keep=patient &y &x)  Z (keep = patient &z);
  set temp;
  int = 1; /* intercept */
  array y_[*]  y1-y5;
  array t_[*]  t1-t5 (0 1 5 9 13);

  /* Create the design matrix for the mean model */
  /* as well as the response.                     */
  do j = 1 to 5;
    y = y_[j];
    if (y ^= .) then do
      y = ^y;           * model prob(good);
      time = t_[j];
      treat = trt * (j>2);
      output XY;
    end;
  end;

  /* Create the design matrix for the association model. */
  do j = 1 to 4;
    if (y_[j] ^= .) then do k = (j+1) to 5;
      if (y_[k] ^= .) then do;
        distance = 1 / abs(t_[j]-t_[k]);
        output Z;
      end;
    end;
  end;

run;

** Each cluster has weight 1 **;
data weight (keep=w);
  set temp;
  w=1;
run;


** Invoke the macro **;

%include "orthdist.mac";


/* In this call to ORTHDIST, Lambda is fixed at 0 (i.e. =ALR) */
%ORTHDIST(xydata=xy, yvar=&y, xvar=&x, id=patient,
          zdata=z,   zvar=&z,
          wdata=weight,  wvar=w, maxiter=20, epsilon=1e-5,
          estlamb = ALR);


/* In this call to ORTHDIST, Lambda is based on the BB model  */
%ORTHDIST(xydata=xy, yvar=&y, xvar=&x, id=patient,
          zdata=z,   zvar=&z,
          wdata=weight,  wvar=w, maxiter=20, epsilon=1e-5,
          estlamb = BB );


/* In this call to ORTHDIST, Lambda is based on the Madsen model  */
%ORTHDIST(xydata=xy, yvar=&y, xvar=&x, id=patient,
          zdata=z,   zvar=&z,
          wdata=weight,  wvar=w, maxiter=20, epsilon=1e-5,
          estlamb = MAD);


/* In this call to ORTHDIST, Lambda is based on the MN model  */
%ORTHDIST(xydata=xy, yvar=&y, xvar=&x, id=patient,
          zdata=z,   zvar=&z,
          wdata=weight,  wvar=w, maxiter=20, epsilon=1e-5,
          estlamb = MN );


